pub struct UpdateUserSshKeyOptions {
pub name: Option<CompactString>,
}Fields
name: Option<CompactString>Trait Implementations
Sourceimpl ComposeSchema for UpdateUserSshKeyOptions
impl ComposeSchema for UpdateUserSshKeyOptions
Sourceimpl Default for UpdateUserSshKeyOptions
impl Default for UpdateUserSshKeyOptions
Sourcefn default() -> UpdateUserSshKeyOptions
fn default() -> UpdateUserSshKeyOptions
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for UpdateUserSshKeyOptions
impl<'de> Deserialize<'de> for UpdateUserSshKeyOptions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for UpdateUserSshKeyOptions
impl Serialize for UpdateUserSshKeyOptions
Sourceimpl ToSchema for UpdateUserSshKeyOptions
impl ToSchema for UpdateUserSshKeyOptions
Sourceimpl Validate for UpdateUserSshKeyOptions
impl Validate for UpdateUserSshKeyOptions
Sourcefn validate_into(
&self,
__garde_user_ctx: &Self::Context,
__garde_path: &mut dyn FnMut() -> Path,
__garde_report: &mut Report,
)
fn validate_into( &self, __garde_user_ctx: &Self::Context, __garde_path: &mut dyn FnMut() -> Path, __garde_report: &mut Report, )
Validates
Self, aggregating all validation errors into Report.fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read morefn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
fn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read moreAuto Trait Implementations
impl Freeze for UpdateUserSshKeyOptions
impl RefUnwindSafe for UpdateUserSshKeyOptions
impl Send for UpdateUserSshKeyOptions
impl Sync for UpdateUserSshKeyOptions
impl Unpin for UpdateUserSshKeyOptions
impl UnwindSafe for UpdateUserSshKeyOptions